pub struct ActivityInstanceDto {
pub id: Option<String>,
pub parent_activity_instance_id: Option<String>,
pub activity_id: Option<String>,
pub activity_name: Option<String>,
pub activity_type: Option<String>,
pub process_instance_id: Option<String>,
pub process_definition_id: Option<String>,
pub child_activity_instances: Option<Vec<ActivityInstanceDto>>,
pub child_transition_instances: Option<Vec<TransitionInstanceDto>>,
pub execution_ids: Option<Vec<String>>,
pub incident_ids: Option<Vec<String>>,
pub incidents: Option<Vec<ActivityInstanceIncidentDto>>,
}Expand description
ActivityInstanceDto : A JSON object corresponding to the Activity Instance tree of the given process instance.
Fields
id: Option<String>The id of the activity instance.
parent_activity_instance_id: Option<String>The id of the parent activity instance, for example a sub process instance.
activity_id: Option<String>The id of the activity.
activity_name: Option<String>The name of the activity
activity_type: Option<String>The type of activity (corresponds to the XML element name in the BPMN 2.0, e.g., ‘userTask’)
process_instance_id: Option<String>The id of the process instance this activity instance is part of.
process_definition_id: Option<String>The id of the process definition.
child_activity_instances: Option<Vec<ActivityInstanceDto>>A list of child activity instances.
child_transition_instances: Option<Vec<TransitionInstanceDto>>A list of child transition instances. A transition instance represents an execution waiting in an asynchronous continuation.
execution_ids: Option<Vec<String>>A list of execution ids.
incident_ids: Option<Vec<String>>A list of incident ids.
incidents: Option<Vec<ActivityInstanceIncidentDto>>A list of JSON objects containing incident specific properties: * id: the id of the incident * activityId: the activity id in which the incident occurred
Implementations
Sourceimpl ActivityInstanceDto
impl ActivityInstanceDto
Sourcepub fn new() -> ActivityInstanceDto
pub fn new() -> ActivityInstanceDto
A JSON object corresponding to the Activity Instance tree of the given process instance.