pub struct CompleteTaskDto {
pub variables: Option<HashMap<String, VariableValueDto>>,
pub with_variables_in_return: Option<bool>,
}Fields
variables: Option<HashMap<String, VariableValueDto>>A JSON object containing variable key-value pairs.
with_variables_in_return: Option<bool>Indicates whether the response should contain the process variables or not. The default is false with a response code of 204. If set to true the response contains the process variables and has a response code of 200. If the task is not associated with a process instance (e.g. if it’s part of a case instance) no variables will be returned.
Implementations
Sourceimpl CompleteTaskDto
impl CompleteTaskDto
pub fn new() -> CompleteTaskDto