pub struct ExternalTaskBpmnError {
pub worker_id: Option<String>,
pub error_code: Option<String>,
pub error_message: Option<String>,
pub variables: Option<HashMap<String, VariableValueDto>>,
}Fields
worker_id: Option<String>The id of the worker that reports the failure. Must match the id of the worker who has most recently locked the task.
error_code: Option<String>An error code that indicates the predefined error. It is used to identify the BPMN error handler.
error_message: Option<String>An error message that describes the error.
variables: Option<HashMap<String, VariableValueDto>>A JSON object containing variable key-value pairs.
Implementations
Sourceimpl ExternalTaskBpmnError
impl ExternalTaskBpmnError
pub fn new() -> ExternalTaskBpmnError