ExternalTaskQueryDto

Struct ExternalTaskQueryDto 

pub struct ExternalTaskQueryDto {
Show 22 fields pub external_task_id: Option<String>, pub external_task_id_in: Option<Vec<String>>, pub topic_name: Option<String>, pub worker_id: Option<String>, pub locked: Option<bool>, pub not_locked: Option<bool>, pub with_retries_left: Option<bool>, pub no_retries_left: Option<bool>, pub lock_expiration_after: Option<String>, pub lock_expiration_before: Option<String>, pub activity_id: Option<String>, pub activity_id_in: Option<Vec<String>>, pub execution_id: Option<String>, pub process_instance_id: Option<String>, pub process_instance_id_in: Option<Vec<String>>, pub process_definition_id: Option<String>, pub tenant_id_in: Option<Vec<String>>, pub active: Option<bool>, pub suspended: Option<bool>, pub priority_higher_than_or_equals: Option<i64>, pub priority_lower_than_or_equals: Option<i64>, pub sorting: Option<Vec<ExternalTaskQueryDtoSorting>>,
}
ExternalTaskQueryDto : A JSON object with the following properties:

Fields

external_task_id: Option<String>

Filter by an external task’s id.

external_task_id_in: Option<Vec<String>>

Filter by the comma-separated list of external task ids.

topic_name: Option<String>

Filter by an external task topic.

worker_id: Option<String>

Filter by the id of the worker that the task was most recently locked by.

locked: Option<bool>

Only include external tasks that are currently locked (i.e., they have a lock time and it has not expired). Value may only be true, as false matches any external task.

not_locked: Option<bool>

Only include external tasks that are currently not locked (i.e., they have no lock or it has expired). Value may only be true, as false matches any external task.

with_retries_left: Option<bool>

Only include external tasks that have a positive (> 0) number of retries (or null). Value may only be true, as false matches any external task.

no_retries_left: Option<bool>

Only include external tasks that have 0 retries. Value may only be true, as false matches any external task.

lock_expiration_after: Option<String>

Restrict to external tasks that have a lock that expires after a given date. By default, the date must have the format yyyy-MM-dd'T'HH:mm:ss.SSSZ, e.g., 2013-01-23T14:42:45.000+0200.

lock_expiration_before: Option<String>

Restrict to external tasks that have a lock that expires before a given date. By default, the date must have the format yyyy-MM-dd'T'HH:mm:ss.SSSZ, e.g., 2013-01-23T14:42:45.000+0200.

activity_id: Option<String>

Filter by the id of the activity that an external task is created for.

activity_id_in: Option<Vec<String>>

Filter by the comma-separated list of ids of the activities that an external task is created for.

execution_id: Option<String>

Filter by the id of the execution that an external task belongs to.

process_instance_id: Option<String>

Filter by the id of the process instance that an external task belongs to.

process_instance_id_in: Option<Vec<String>>

Filter by a comma-separated list of process instance ids that an external task may belong to.

process_definition_id: Option<String>

Filter by the id of the process definition that an external task belongs to.

tenant_id_in: Option<Vec<String>>

Filter by a comma-separated list of tenant ids. An external task must have one of the given tenant ids.

active: Option<bool>

Only include active tasks. Value may only be true, as false matches any external task.

suspended: Option<bool>

Only include suspended tasks. Value may only be true, as false matches any external task.

priority_higher_than_or_equals: Option<i64>

Only include jobs with a priority higher than or equal to the given value. Value must be a valid long value.

priority_lower_than_or_equals: Option<i64>

Only include jobs with a priority lower than or equal to the given value. Value must be a valid long value.

sorting: Option<Vec<ExternalTaskQueryDtoSorting>>

A JSON array of criteria to sort the result by. Each element of the array is a JSON object that specifies one ordering. The position in the array identifies the rank of an ordering, i.e., whether it is primary, secondary, etc. The ordering objects have the following properties: Note: The sorting properties will not be applied to the External Task count query.

Implementations

Source

impl ExternalTaskQueryDto

pub fn new() -> ExternalTaskQueryDto

A JSON object with the following properties: