FetchExternalTaskTopicDto

Struct FetchExternalTaskTopicDto 

pub struct FetchExternalTaskTopicDto {
Show 14 fields pub topic_name: String, pub lock_duration: Option<i64>, pub variables: Option<Vec<String>>, pub local_variables: Option<bool>, pub business_key: Option<String>, pub process_definition_id: Option<String>, pub process_definition_id_in: Option<Vec<String>>, pub process_definition_key: Option<String>, pub process_definition_key_in: Option<Vec<String>>, pub process_definition_version_tag: Option<String>, pub without_tenant_id: Option<bool>, pub tenant_id_in: Option<Vec<String>>, pub process_variables: Option<HashMap<String, Value>>, pub deserialize_values: Option<bool>,
}

Fields

topic_name: String

Mandatory. The topic’s name.

lock_duration: Option<i64>

Mandatory. The duration to lock the external tasks for in milliseconds.

variables: Option<Vec<String>>

A JSON array of String values that represent variable names. For each result task belonging to this topic, the given variables are returned as well if they are accessible from the external task’s execution. If not provided - all variables will be fetched.

local_variables: Option<bool>

If true only local variables will be fetched.

business_key: Option<String>

A String value which enables the filtering of tasks based on process instance business key.

process_definition_id: Option<String>

Filter tasks based on process definition id.

process_definition_id_in: Option<Vec<String>>

Filter tasks based on process definition ids.

process_definition_key: Option<String>

Filter tasks based on process definition key.

process_definition_key_in: Option<Vec<String>>

Filter tasks based on process definition keys.

process_definition_version_tag: Option<String>

Filter tasks based on process definition version tag.

without_tenant_id: Option<bool>

Filter tasks without tenant id.

tenant_id_in: Option<Vec<String>>

Filter tasks based on tenant ids.

process_variables: Option<HashMap<String, Value>>

A JSON object used for filtering tasks based on process instance variable values. A property name of the object represents a process variable name, while the property value represents the process variable value to filter tasks by.

deserialize_values: Option<bool>

Determines whether serializable variable values (typically variables that store custom Java objects) should be deserialized on server side (default false). If set to true, a serializable variable will be deserialized on server side and transformed to JSON using Jackson’s POJO/bean property introspection feature. Note that this requires the Java classes of the variable value to be on the REST API’s classpath. If set to false, a serializable variable will be returned in its serialized format. For example, a variable that is serialized as XML will be returned as a JSON string containing XML.

Implementations