pub struct MultiFormVariableBinaryDto {
pub data: Option<PathBuf>,
pub value_type: Option<ValueType>,
}Fields
data: Option<PathBuf>The binary data to be set. For File variables, this multipart can contain the filename, binary value and MIME type of the file variable to be set Only the filename is mandatory.
value_type: Option<ValueType>The name of the variable type. Either Bytes for a byte array variable or File for a file variable.
Implementations
Sourceimpl MultiFormVariableBinaryDto
impl MultiFormVariableBinaryDto
pub fn new() -> MultiFormVariableBinaryDto