pub struct ProcessInstanceModificationDto {
pub skip_custom_listeners: Option<bool>,
pub skip_io_mappings: Option<bool>,
pub instructions: Option<Vec<ProcessInstanceModificationInstructionDto>>,
pub annotation: Option<String>,
}Fields
skip_custom_listeners: Option<bool>Skip execution listener invocation for activities that are started or ended as part of this request.
skip_io_mappings: Option<bool>Skip execution of input/output variable mappings for activities that are started or ended as part of this request.
instructions: Option<Vec<ProcessInstanceModificationInstructionDto>>JSON array of modification instructions. The instructions are executed in the order they are in.
annotation: Option<String>An arbitrary text annotation set by a user for auditing reasons.
Implementations