ProcessInstanceQueryDto

Struct ProcessInstanceQueryDto 

pub struct ProcessInstanceQueryDto {
Show 31 fields pub deployment_id: Option<String>, pub process_definition_id: Option<String>, pub process_definition_key: Option<String>, pub process_definition_key_in: Option<Vec<String>>, pub process_definition_key_not_in: Option<Vec<String>>, pub business_key: Option<String>, pub business_key_like: Option<String>, pub case_instance_id: Option<String>, pub super_process_instance: Option<String>, pub sub_process_instance: Option<String>, pub super_case_instance: Option<String>, pub sub_case_instance: Option<String>, pub active: Option<bool>, pub suspended: Option<bool>, pub process_instance_ids: Option<Vec<String>>, pub with_incident: Option<bool>, pub incident_id: Option<String>, pub incident_type: Option<String>, pub incident_message: Option<String>, pub incident_message_like: Option<String>, pub tenant_id_in: Option<Vec<String>>, pub without_tenant_id: Option<bool>, pub process_definition_without_tenant_id: Option<bool>, pub activity_id_in: Option<Vec<String>>, pub root_process_instances: Option<bool>, pub leaf_process_instances: Option<bool>, pub variables: Option<Vec<VariableQueryParameterDto>>, pub variable_names_ignore_case: Option<bool>, pub variable_values_ignore_case: Option<bool>, pub or_queries: Option<Vec<ProcessInstanceQueryDto>>, pub sorting: Option<Vec<ProcessInstanceQueryDtoSorting>>,
}
ProcessInstanceQueryDto : A process instance query which defines a group of process instances

Fields

deployment_id: Option<String>

Filter by the deployment the id belongs to.

process_definition_id: Option<String>

Filter by the process definition the instances run on.

process_definition_key: Option<String>

Filter by the key of the process definition the instances run on.

process_definition_key_in: Option<Vec<String>>

Filter by a list of process definition keys. A process instance must have one of the given process definition keys. Must be a JSON array of Strings.

process_definition_key_not_in: Option<Vec<String>>

Exclude instances by a list of process definition keys. A process instance must not have one of the given process definition keys. Must be a JSON array of Strings.

business_key: Option<String>

Filter by process instance business key.

business_key_like: Option<String>

Filter by process instance business key that the parameter is a substring of.

case_instance_id: Option<String>

Filter by case instance id.

super_process_instance: Option<String>

Restrict query to all process instances that are sub process instances of the given process instance. Takes a process instance id.

sub_process_instance: Option<String>

Restrict query to all process instances that have the given process instance as a sub process instance. Takes a process instance id.

super_case_instance: Option<String>

Restrict query to all process instances that are sub process instances of the given case instance. Takes a case instance id.

sub_case_instance: Option<String>

Restrict query to all process instances that have the given case instance as a sub case instance. Takes a case instance id.

active: Option<bool>

Only include active process instances. Value may only be true, as false is the default behavior.

suspended: Option<bool>

Only include suspended process instances. Value may only be true, as false is the default behavior.

process_instance_ids: Option<Vec<String>>

Filter by a list of process instance ids. Must be a JSON array of Strings.

with_incident: Option<bool>

Filter by presence of incidents. Selects only process instances that have an incident.

incident_id: Option<String>

Filter by the incident id.

incident_type: Option<String>

Filter by the incident type. See the User Guide for a list of incident types.

incident_message: Option<String>

Filter by the incident message. Exact match.

incident_message_like: Option<String>

Filter by the incident message that the parameter is a substring of.

tenant_id_in: Option<Vec<String>>

Filter by a list of tenant ids. A process instance must have one of the given tenant ids. Must be a JSON array of Strings.

without_tenant_id: Option<bool>

Only include process instances which belong to no tenant. Value may only be true, as false is the default behavior.

process_definition_without_tenant_id: Option<bool>

Only include process instances which process definition has no tenant id.

activity_id_in: Option<Vec<String>>

Filter by a list of activity ids. A process instance must currently wait in a leaf activity with one of the given activity ids.

root_process_instances: Option<bool>

Restrict the query to all process instances that are top level process instances.

leaf_process_instances: Option<bool>

Restrict the query to all process instances that are leaf instances. (i.e. don’t have any sub instances)

variables: Option<Vec<VariableQueryParameterDto>>

A JSON array to only include process instances that have variables with certain values. The array consists of objects with the three properties name, operator and value. name (String) is the variable name, operator (String) is the comparison operator to be used and value the variable value. The value may be String, Number or Boolean. Valid operator values are: eq - equal to; neq - not equal to; gt - greater than; gteq - greater than or equal to; lt - lower than; lteq - lower than or equal to; like.

variable_names_ignore_case: Option<bool>

Match all variable names in this query case-insensitively. If set to true variableName and variablename are treated as equal.

variable_values_ignore_case: Option<bool>

Match all variable values in this query case-insensitively. If set to true variableValue and variablevalue are treated as equal.

or_queries: Option<Vec<ProcessInstanceQueryDto>>

A JSON array of nested process instance queries with OR semantics. A process instance matches a nested query if it fulfills at least one of the query’s predicates. With multiple nested queries, a process instance must fulfill at least one predicate of each query (Conjunctive Normal Form). All process instance query properties can be used except for: sorting See the User guide for more information about OR queries.

sorting: Option<Vec<ProcessInstanceQueryDtoSorting>>

Apply sorting of the result

Implementations

Source

impl ProcessInstanceQueryDto

pub fn new() -> ProcessInstanceQueryDto

A process instance query which defines a group of process instances