pub struct ProcessInstanceWithVariablesDto {
pub variables: Option<HashMap<String, VariableValueDto>>,
pub id: Option<String>,
pub definition_id: Option<String>,
pub business_key: Option<String>,
pub case_instance_id: Option<String>,
pub ended: Option<bool>,
pub suspended: Option<bool>,
pub tenant_id: Option<String>,
pub links: Option<Vec<AtomLink>>,
}Fields
variables: Option<HashMap<String, VariableValueDto>>The id of the process instance.
id: Option<String>The id of the process instance.
definition_id: Option<String>The id of the process definition that this process instance belongs to.
business_key: Option<String>The business key of the process instance.
case_instance_id: Option<String>The id of the case instance associated with the process instance.
ended: Option<bool>A flag indicating whether the process instance has ended or not. Deprecated: will always be false!
suspended: Option<bool>A flag indicating whether the process instance is suspended or not.
tenant_id: Option<String>The tenant id of the process instance.
links: Option<Vec<AtomLink>>The links associated to this resource, with method, href and rel.
Implementations