RestartProcessInstanceDto

Struct RestartProcessInstanceDto 

pub struct RestartProcessInstanceDto {
    pub process_instance_ids: Option<Vec<String>>,
    pub historic_process_instance_query: Option<HistoricProcessInstanceQueryDto>,
    pub skip_custom_listeners: Option<bool>,
    pub skip_io_mappings: Option<bool>,
    pub initial_variables: Option<bool>,
    pub without_business_key: Option<bool>,
    pub instructions: Option<Vec<RestartProcessInstanceModificationInstructionDto>>,
}

Fields

process_instance_ids: Option<Vec<String>>

A list of process instance ids to restart.

historic_process_instance_query: Option<HistoricProcessInstanceQueryDto>skip_custom_listeners: Option<bool>

Skip execution listener invocation for activities that are started as part of this request.

skip_io_mappings: Option<bool>

Skip execution of input/output variable mappings for activities that are started as part of this request.

initial_variables: Option<bool>

Set the initial set of variables during restart. By default, the last set of variables is used.

without_business_key: Option<bool>

Do not take over the business key of the historic process instance.

instructions: Option<Vec<RestartProcessInstanceModificationInstructionDto>>

Optional. A JSON array of instructions that specify which activities to start the process instance at. If this property is omitted, the process instance starts at its default blank start event.

Implementations