pub struct RestartProcessInstanceModificationInstructionDto {
pub _type: Type,
pub activity_id: Option<String>,
pub transition_id: Option<String>,
}Fields
_type: TypeMandatory. One of the following values: startBeforeActivity, startAfterActivity, startTransition. * A startBeforeActivity instruction requests to enter a given activity. * A startAfterActivity instruction requests to execute the single outgoing sequence flow of a given activity. * A startTransition instruction requests to execute a specific sequence flow.
activity_id: Option<String>Can be used with instructions of types startBeforeActivity and startAfterActivity. Specifies the sequence flow to start.
transition_id: Option<String>Can be used with instructions of types startTransition. Specifies the sequence flow to start.
Implementations