pub struct StartProcessInstanceDto {
pub business_key: Option<String>,
pub variables: Option<HashMap<String, VariableValueDto>>,
pub case_instance_id: Option<String>,
pub start_instructions: Option<Vec<ProcessInstanceModificationInstructionDto>>,
pub skip_custom_listeners: Option<bool>,
pub skip_io_mappings: Option<bool>,
pub with_variables_in_return: Option<bool>,
}Fields
business_key: Option<String>The business key of the process instance.
variables: Option<HashMap<String, VariableValueDto>>case_instance_id: Option<String>The case instance id the process instance is to be initialized with.
start_instructions: Option<Vec<ProcessInstanceModificationInstructionDto>>Optional. A JSON array of instructions that specify which activities to start the process instance at. If this property is omitted, the process instance starts at its default blank start event.
skip_custom_listeners: Option<bool>Skip execution listener invocation for activities that are started or ended as part of this request. Note: This option is currently only respected when start instructions are submitted via the startInstructions property.
skip_io_mappings: Option<bool>Skip execution of input/output variable mappings for activities that are started or ended as part of this request. Note: This option is currently only respected when start instructions are submitted via the startInstructions property.
with_variables_in_return: Option<bool>Indicates if the variables, which was used by the process instance during execution, should be returned. Default value: false
Implementations
Sourceimpl StartProcessInstanceDto
impl StartProcessInstanceDto
pub fn new() -> StartProcessInstanceDto