pub struct StartProcessInstanceFormDto {
pub variables: Option<HashMap<String, VariableValueDto>>,
pub business_key: Option<String>,
}Fields
variables: Option<HashMap<String, VariableValueDto>>business_key: Option<String>The business key the process instance is to be initialized with. The business key uniquely identifies the process instance in the context of the given process definition.
Implementations
Sourceimpl StartProcessInstanceFormDto
impl StartProcessInstanceFormDto
pub fn new() -> StartProcessInstanceFormDto