pub struct TriggerVariableValueDto {
pub local: Option<bool>,
pub value: Option<Value>,
pub _type: Option<String>,
pub value_info: Option<HashMap<String, Value>>,
}Fields
local: Option<bool>Indicates whether the variable should be a local variable or not. If set to true, the variable becomes a local variable of the execution entering the target activity.
value: Option<Value>The variable’s value. Value differs depending on the variable’s type and on the deserializeValues parameter.
_type: Option<String>The value type of the variable.
value_info: Option<HashMap<String, Value>>A JSON object containing additional, value-type-dependent properties. For serialized variables of type Object, the following properties can be provided: * objectTypeName: A string representation of the object’s type name. * serializationDataFormat: The serialization format used to store the variable. For serialized variables of type File, the following properties can be provided: * filename: The name of the file. This is not the variable name but the name that will be used when downloading the file again. * mimetype: The MIME type of the file that is being uploaded. * encoding: The encoding of the file that is being uploaded.
Implementations
Sourceimpl TriggerVariableValueDto
impl TriggerVariableValueDto
pub fn new() -> TriggerVariableValueDto