pub struct CompleteExternalTaskDto {
pub worker_id: Option<String>,
pub variables: Option<HashMap<String, VariableValueDto>>,
pub local_variables: Option<HashMap<String, VariableValueDto>>,
}Fields
worker_id: Option<String>The id of the worker that completes the task. Must match the id of the worker who has most recently locked the task.
variables: Option<HashMap<String, VariableValueDto>>A JSON object containing variable key-value pairs. Each key is a variable name and each value a JSON variable value object with the following properties:
local_variables: Option<HashMap<String, VariableValueDto>>A JSON object containing local variable key-value pairs. Local variables are set only in the scope of external task. Each key is a variable name and each value a JSON variable value object with the following properties:
Implementations
Sourceimpl CompleteExternalTaskDto
impl CompleteExternalTaskDto
pub fn new() -> CompleteExternalTaskDto