pub struct TaskDto {Show 21 fields
pub id: Option<String>,
pub name: Option<String>,
pub assignee: Option<String>,
pub owner: Option<String>,
pub created: Option<String>,
pub due: Option<String>,
pub follow_up: Option<String>,
pub delegation_state: Option<DelegationState>,
pub description: Option<String>,
pub execution_id: Option<String>,
pub parent_task_id: Option<String>,
pub priority: Option<i32>,
pub process_definition_id: Option<String>,
pub process_instance_id: Option<String>,
pub case_execution_id: Option<String>,
pub case_definition_id: Option<String>,
pub case_instance_id: Option<String>,
pub task_definition_key: Option<String>,
pub suspended: Option<bool>,
pub form_key: Option<String>,
pub tenant_id: Option<String>,
}Fields
id: Option<String>The task id.
name: Option<String>The task name.
assignee: Option<String>The assignee’s id.
owner: Option<String>The owner’s id.
created: Option<String>The date the task was created on. Default format yyyy-MM-dd'T'HH:mm:ss.SSSZ.
due: Option<String>The task’s due date. Default format yyyy-MM-dd'T'HH:mm:ss.SSSZ.
follow_up: Option<String>The follow-up date for the task. Default format yyyy-MM-dd'T'HH:mm:ss.SSSZ.
delegation_state: Option<DelegationState>The task’s delegation state. Possible values are PENDING and RESOLVED.
description: Option<String>The task’s description.
execution_id: Option<String>The id of the execution the task belongs to.
parent_task_id: Option<String>The id the parent task, if this task is a subtask.
priority: Option<i32>The task’s priority.
process_definition_id: Option<String>The id of the process definition the task belongs to.
process_instance_id: Option<String>The id of the process instance the task belongs to.
case_execution_id: Option<String>The id of the case execution the task belongs to.
case_definition_id: Option<String>The id of the case definition the task belongs to.
case_instance_id: Option<String>The id of the case instance the task belongs to.
task_definition_key: Option<String>The task’s key.
suspended: Option<bool>Whether the task belongs to a process instance that is suspended.
form_key: Option<String>If not null, the form key for the task.
tenant_id: Option<String>If not null, the tenant id of the task.
Implementations